==> roughpy-0.0.8.tar.gz: roughpy-0.0.8/scalars/src/ScalarTests.h <==
// Copyright (c) 2023 RoughPy Developers. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors
// may be used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

//
// Created by sam on 15/03/23.
//

#ifndef ROUGHPY_SCALARTESTS_H
#define ROUGHPY_SCALARTESTS_H

#include <gtest/gtest.h>

#include <roughpy/scalars/scalar_type.h>
#include <roughpy/scalars/types.h>

namespace rpy {
namespace scalars {
namespace testing {

class ScalarTests : public ::testing::Test
{
public:
    const scalars::ScalarType* dtype;
    const scalars::ScalarType* ftype;

    ScalarTests()
        : dtype(ScalarType::of<double>()), ftype(ScalarType::of<float>())
    {}
};

}// namespace testing
}// namespace scalars
}// namespace rpy

#endif// ROUGHPY_SCALARTESTS_H

==> roughpy-0.1.1.tar.gz: roughpy-0.1.1/scalars/src/ScalarTests.h <==
//
// Created by user on 08/11/23.
//

#ifndef ROUGHPY_SCALARS_SRC_SCALARTESTS_H_
#define ROUGHPY_SCALARS_SRC_SCALARTESTS_H_

// Copyright (c) 2023 RoughPy Developers. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors
// may be used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

//
// Created by sam on 15/03/23.
//

#ifndef ROUGHPY_SCALARTESTS_H
#define ROUGHPY_SCALARTESTS_H

#include <gtest/gtest.h>

#include <roughpy/scalars/scalar_type.h>
#include <roughpy/scalars/scalar_types.h>

namespace rpy {
namespace scalars {
namespace testing {

class ScalarTests : public ::testing::Test
{
public:
    const scalars::ScalarType* dtype;
    const scalars::ScalarType* ftype;

    ScalarTests()
        : dtype(*ScalarType::of<double>()), ftype(*ScalarType::of<float>())
    {}
};

}// namespace testing
}// namespace scalars
}// namespace rpy

#endif// ROUGHPY_SCALARTESTS_H


#endif// ROUGHPY_SCALARS_SRC_SCALARTESTS_H_
